@@ -12,7 +12,7 @@ A full GN block has the following computation steps
 from typing import Dict, Sequence
 
 import tensorflow as tf
-from tensorflow.keras import regularizers, constraints, initializers
+from tensorflow.keras import constraints, initializers, regularizers
 from tensorflow.keras.layers import Layer
 
 from megnet import activations
