@@ -3,7 +3,7 @@ Set2Set implementation
 """
 import tensorflow as tf
 import tensorflow.keras.backend as kb
-from tensorflow.keras import activations, initializers, regularizers, constraints
+from tensorflow.keras import activations, constraints, initializers, regularizers
 from tensorflow.keras.layers import Layer
 
 
