@@ -1,15 +1,16 @@
+import csv
 import os
 import unittest
 
 import numpy as np
-import tensorflow as tf
-import tensorflow.keras.backend as kb
 from monty.tempfile import ScratchDir
+from tensorflow.keras.callbacks import CSVLogger
 from tensorflow.keras.layers import Dense, Input
 from tensorflow.keras.models import Model
+from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.utils import Sequence
 
-from megnet.callbacks import ManualStop, ModelCheckpointMAE, ReduceLRUponNan
+from megnet.callbacks import EarlyStopping, ManualStop, ModelCheckpointMAE
 from megnet.layers import MEGNetLayer
 
 
@@ -79,14 +80,9 @@ class TestCallBack(unittest.TestCase):
             self.assertEqual(epoch_count, 4)
             os.remove("STOP")
 
-    def test_reduce_lr_upon_nan(self):
+    def test_early_stopping(self):
+        patience = 1
         with ScratchDir("."):
-            callbacks = [ReduceLRUponNan(patience=100)]
-            self.assertAlmostEqual(float(kb.get_value(self.model.optimizer.lr)), 1e-3)
-            gen = Generator(self.x, np.array([1, np.nan]).reshape((1, 2, 1)))
-            self.model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=0)
-            self.assertAlmostEqual(float(kb.get_value(self.model.optimizer.lr)), 0.5e-3)
-
             inp = [
                 Input(shape=(None, self.n_feature)),
                 Input(shape=(None, self.n_bond_features)),
@@ -107,7 +103,8 @@ class TestCallBack(unittest.TestCase):
             out = layer(inp)
             out = Dense(1)(out[2])
             model = Model(inputs=inp, outputs=out)
-            model.compile(loss="mse", optimizer="adam")
+            # Learning rate to 0 so model doesn't actually optimize
+            model.compile(loss="mse", optimizer=Adam(learning_rate=0))
             x = [
                 np.random.normal(size=(1, 4, self.n_feature)),
                 np.random.normal(size=(1, 6, self.n_bond_features)),
@@ -120,21 +117,20 @@ class TestCallBack(unittest.TestCase):
             y = np.random.normal(size=(1, 2, 1))
             train_gen = Generator(x, y)
 
+            fpath = "./val_mae_{epoch:05d}_{val_mae:.6f}.hdf5"
             callbacks = [
-                ReduceLRUponNan(filepath="./val_mae_{epoch:05d}_{val_mae:.6f}.hdf5", patience=100),
-                ModelCheckpointMAE(
-                    filepath="./val_mae_{epoch:05d}_{val_mae:.6f}.hdf5", val_gen=train_gen, steps_per_val=1
-                ),
+                ModelCheckpointMAE(filepath=fpath, val_gen=train_gen, steps_per_val=1),
+                EarlyStopping(filepath=fpath, patience=patience),
+                CSVLogger("history.csv", append=True),
             ]
-            # 1. involve training and saving
-            model.fit(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
-            # 2. throw nan loss, trigger ReduceLRUponNan
-            model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=1)
-            model.fit(gen, steps_per_epoch=1, epochs=1, callbacks=callbacks, verbose=1)
-            # 3. Normal training, recover saved model from 1
-            model.fit(train_gen, steps_per_epoch=1, epochs=2, callbacks=callbacks, verbose=1)
 
-            self.assertAlmostEqual(float(kb.get_value(model.optimizer.lr)), 0.25e-3)
+            max_epochs = 1000
+            model.fit(train_gen, steps_per_epoch=1, epochs=max_epochs, callbacks=callbacks, verbose=1)
+
+            with open("history.csv") as fr:
+                history = list(csv.DictReader(fr))
+
+            self.assertTrue(len(history) < max_epochs)
 
 
 if __name__ == "__main__":
