@@ -1,9 +1,9 @@
 """Define several typing for convenient use"""
 
-from typing import Union, Callable, Optional, Any, List
+from typing import Any, Callable, List, Optional, Union
 
 import numpy as np
-from pymatgen.core import Structure, Molecule
+from pymatgen.core import Molecule, Structure
 
 OptStrOrCallable = Optional[Union[str, Callable[..., Any]]]
 StructureOrMolecule = Union[Structure, Molecule]
